=======
History
=======

0.9.0 (2017-10-21)
------------------

* Python 2.7 support

0.8.0 (2017-10-21)
------------------

* Good test coverage
* Things are mostly working
* Rename functionality
* List/info
* Much more

0.4.0 (2017-10-08)
------------------

* Started a complete rewrite, mainly focusing on using python 3.6
* Test on PyPI.. Non working version.

0.2 (2017-10-07)
------------------

* Checkpoint of the old version working only with 2.x. This checkpoint contains code from many years ago.
